@@ -5,10 +5,10 @@ use AnyEvent::mDNS;
 my $cv = AnyEvent->condvar;
 
 my $proto = shift || "_http._tcp";
-AnyEvent::mDNS::discover $proto, on_timeout => $cv, sub {
+my $s = AnyEvent::mDNS::discover $proto, on_found => sub {
     my $service = shift;
     warn "Found $service->{name} ($service->{proto}) running on $service->{host}:$service->{port}\n";
-};
+}, $cv;
 
 my @all = $cv->recv;
 warn "Found ", scalar @all, " service(s)\n";
